==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/uk.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ви увімкнули двофакторну авторизацію за допомогою одноразового коду",
    "You disabled TOTP two-factor authentication for your account" : "Ви вимкнули двофакторну авторизацію за допомогою одноразового коду",
    "TOTP two-factor authentication disabled by the administration" : "Двофакторну авторизацію TOTP вимкнено адміністратором",
    "TOTP (Authenticator app)" : "Застосунок двофакторної авторизації",
    "Authenticate with a TOTP app" : "Отримати одноразовий код у застосунку авторизації на вашому пристрої",
    "Two-Factor TOTP Provider" : "Постачальник послуг двофакторної авторизації TOTP",
    "Two-factor TOTP provider" : "Постачальник другого фактору TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Постачальник двофакторної авторизації для TOTP (RFC 6238)",
    "Could not enable TOTP" : "Не вдалося увімкнути авторизацію за допомогою одноразового коду",
    "Could not verify your key. Please try again" : "Не вдалося перевірити ваш код. Спробуйте ще раз",
    "Enable TOTP" : "Увімкнути авторизацію за допомогою одноразового коду",
    "Your new TOTP secret is:" : "Ваш новий одноразовий код:",
    "For quick setup, scan this QR code with your TOTP app:" : "Для швидкого налаштування відскануйте цей QR-код у вашому застосунку з авторизації за допомогою одноразового паролю:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Після налаштування вашого застосунку введіть цей тестовий код для здійснення перевірки коректності роботи авторизації:",
    "Authentication code" : "Код авторизації",
    "Verify" : "Перевірити",
    "Get the authentication code from the two-factor authentication app on your device." : "Зазначте одноразовий код доступу, який було зґенеровано у застосунку двофакторної авторизації на вашому пристрої.",
    "Submit" : "Продовжити"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/twofactor_totp/l10n/uk.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Ви увімкнули двофакторну авторизацію за допомогою одноразового коду",
    "You disabled TOTP two-factor authentication for your account" : "Ви вимкнули двофакторну авторизацію за допомогою одноразового коду",
    "TOTP two-factor authentication disabled by the administration" : "Двофакторну авторизацію TOTP вимкнено адміністратором",
    "TOTP (Authenticator app)" : "Застосунок двофакторної авторизації",
    "Authenticate with a TOTP app" : "Отримати одноразовий код у застосунку авторизації на вашому пристрої",
    "Two-Factor TOTP Provider" : "Постачальник послуг двофакторної авторизації TOTP",
    "Two-factor TOTP provider" : "Постачальник другого фактора TOTP",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Постачальник двофакторної авторизації для TOTP (RFC 6238)",
    "Could not enable TOTP" : "Не вдалося увімкнути авторизацію за допомогою одноразового коду",
    "Could not verify your key. Please try again" : "Не вдалося перевірити ваш код. Спробуйте ще раз",
    "Could not confirm TOTP" : "Не вдалося підтвердити одноразовий код (TOTP)",
    "Enable TOTP" : "Увімкнути авторизацію за допомогою одноразового коду",
    "Your new TOTP secret is:" : "Ваш новий одноразовий код:",
    "For quick setup, scan this QR code with your TOTP app:" : "Для швидкого налаштування відскануйте цей QR-код у вашому застосунку з авторизації за допомогою одноразового пароля:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Після налаштування вашого застосунку введіть цей тестовий код для здійснення перевірки коректності роботи авторизації:",
    "Authentication code" : "Код авторизації",
    "Verify" : "Перевірити",
    "Get the authentication code from the two-factor authentication app on your device." : "Зазначте одноразовий код доступу, який було зґенеровано у застосунку двофакторної авторизації на вашому пристрої.",
    "Submit" : "Продовжити"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
